@@ -14,6 +14,7 @@ class WordSet {
 public:
   void add_word(const char *name, Stamp stamp, bool approve,
 		const char *idx, const char *word);
+  void write_words(FILE *fp);
 protected:
   Word *find_word(const char *idx, const char *word);
 public:
@@ -30,7 +31,6 @@ public:
 
   void print_index(FILE *fp);
 private:
-  void do_write(FILE *fp);
   //
   char *m_file_name;
   int m_idx;
